@@ -74,8 +74,6 @@ class Tools:
 
         if df.crs.to_string() != "EPSG:4326":
             df = df.to_crs(epsg=4326)
-        # TODO: Explode multipolygons (if neccessary as union in aoi anyway most often).
-        # TODO: Have both bboxes for each feature and overall?
         if as_dataframe:
             return df
         else:
@@ -115,8 +113,8 @@ class Tools:
         else:
             return example_aoi
 
-    # pylint: disable=no-self-use
-    def draw_aoi(self):
+    @staticmethod
+    def draw_aoi():
         """
         Displays an interactive map to draw an aoi by hand, returns the folium object if
         not run in a Jupyter notebook.
@@ -148,7 +146,7 @@ class Tools:
         as_dataframe=False,
     ) -> Union[List[Dict], dict]:
         """
-        Gets a list of all public blocks on the marketplace.
+        Gets a list of all public blocks on the marketplace. Can not access custom blocks.
 
         Args:
             block_type: Optionally filters to "data" or "processing" blocks, default None.
@@ -204,6 +202,7 @@ class Tools:
         """
         Gets the detailed information about a specific public block from
         the server, includes all manifest.json and marketplace.json contents.
+        Can not access custom blocks.
 
         Args:
             block_id: The block id.
